﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.InputSystem;

public class BlockSpawner : MonoBehaviour
{
    [SerializeField]
    private GameObject _blockToPlace;
    public GameObject BlockToPlace
    {
        get
        {
            return _blockToPlace;
        }
        set
        {
            DisablePreviewMode();
            _blockToPlace = value;
        }
    }

    public float spawnDistance = 3f;

    private GameObject _blockInstance;

    private bool _isPreview = false;


    public void Update()
    {
        if (_blockInstance == null) return;

        _blockInstance.transform.position = transform.position + transform.forward * spawnDistance;
        _blockInstance.transform.rotation = transform.rotation;
    }

    public void OnPlaceBlock()
    {
        if (!_isPreview) return;
        _blockInstance = null;
        DisablePreviewMode();
    }

    public void OnTogglePreviewMode(InputValue value)
    {
        float valueAsFloat = value.Get<float>();

        if (valueAsFloat == 1f) EnablePreviewMode();
        else DisablePreviewMode();
    }

    private void EnablePreviewMode()
    {
        if (_blockToPlace == null) return;

        Vector3 pos = transform.position + transform.forward * spawnDistance;
        Quaternion rot = transform.rotation;
        _blockInstance = Instantiate(_blockToPlace, pos, rot);
        _isPreview = true;
    }

    private void DisablePreviewMode()
    {
        Destroy(_blockInstance);
        Debug.Log("disabled");
        _isPreview = false;
    }
}
